Modified: subversion/trunk/subversion/svn/cl.h
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/cl.h?rev=1618906&r1=1618905&r2=1618906&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/cl.h (original)
+++ subversion/trunk/subversion/svn/cl.h Tue Aug 19 17:26:20 2014
@@ -393,7 +393,7 @@ svn_cl__get_conflict_func_interactive_ba
  */
 svn_error_t *
 svn_cl__conflict_func_interactive(svn_wc_conflict_result_t **result,
-                                  const svn_wc_conflict_description3_t *desc,
+                                  const svn_wc_conflict_description2_t *desc,
                                   void *baton,
                                   apr_pool_t *result_pool,
                                   apr_pool_t *scratch_pool);

Modified: subversion/trunk/subversion/svn/conflict-callbacks.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/conflict-callbacks.c?rev=1618906&r1=1618905&r2=1618906&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/info-cmd.c (original)
+++ subversion/trunk/subversion/svn/info-cmd.c Tue Aug 19 17:26:20 2014
@@ -238,9 +238,9 @@ print_info_xml(void *baton,
 
       for (i = 0; i < info->wc_info->conflicts->nelts; i++)
         {
-          const svn_wc_conflict_description3_t *conflict =
-                      APR_ARRAY_IDX(info->wc_info->conflicts2, i,
-                                    const svn_wc_conflict_description3_t *);
+          const svn_wc_conflict_description2_t *conflict =
+                      APR_ARRAY_IDX(info->wc_info->conflicts, i,
+                                    const svn_wc_conflict_description2_t *);
 
           SVN_ERR(svn_cl__append_conflict_info_xml(sb, conflict, pool));
         }
@@ -445,9 +445,9 @@ print_info(void *baton,
 
           for (i = 0; i < info->wc_info->conflicts->nelts; i++)
             {
-              const svn_wc_conflict_description3_t *conflict =
-                    APR_ARRAY_IDX(info->wc_info->conflicts2, i,
-                                  const svn_wc_conflict_description3_t *);
+              const svn_wc_conflict_description2_t *conflict =
+                    APR_ARRAY_IDX(info->wc_info->conflicts, i,
+                                  const svn_wc_conflict_description2_t *);
               const char *desc;
 
               switch (conflict->kind)
@@ -479,8 +479,8 @@ print_info(void *baton,
                     if (! printed_prop_conflict_file)
                       SVN_ERR(svn_cmdline_printf(pool,
                                 _("Conflict Properties File: %s\n"),
-                                svn_dirent_local_style(
-                                  conflict->prop_reject_abspath, pool)));
+                                svn_dirent_local_style(conflict->their_abspath,
+                                                       pool)));
                     printed_prop_conflict_file = TRUE;
                   break;
 
@@ -502,9 +502,9 @@ print_info(void *baton,
           {
             const char *src_left_version;
             const char *src_right_version;
-            const svn_wc_conflict_description3_t *conflict =
-                  APR_ARRAY_IDX(info->wc_info->conflicts2, 0,
-                                const svn_wc_conflict_description3_t *);
+            const svn_wc_conflict_description2_t *conflict =
+                  APR_ARRAY_IDX(info->wc_info->conflicts, 0,
+                                const svn_wc_conflict_description2_t *);
 
             src_left_version =
                         svn_cl__node_description(conflict->src_left_version,

Modified: subversion/trunk/subversion/svn/status.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/status.c?rev=1618906&r1=1618905&r2=1618906&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/status.c (original)
+++ subversion/trunk/subversion/svn/status.c Tue Aug 19 17:26:20 2014
@@ -284,7 +284,7 @@ print_status(const char *target_abspath,
 
       if (tree_conflicted)
         {
-          const svn_wc_conflict_description3_t *tree_conflict;
+          const svn_wc_conflict_description2_t *tree_conflict;
           SVN_ERR(svn_wc__get_tree_conflict(&tree_conflict, ctx->wc_ctx,
                                             local_abspath, pool, pool));
           SVN_ERR_ASSERT(tree_conflict != NULL);

Modified: subversion/trunk/subversion/tests/libsvn_wc/conflict-data-test.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/libsvn_wc/conflict-data-test.c?rev=1618906&r1=1618905&r2=1618906&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/libsvn_wc/conflict-data-test.c (original)
+++ subversion/trunk/subversion/tests/libsvn_wc/conflict-data-test.c Tue Aug 19 
17:26:20 2014
@@ -88,8 +88,8 @@ compare_version(const svn_wc_conflict_ve
  * (including names of temporary files), or are both NULL.  Return an
  * error if not. */
 static svn_error_t *
-compare_conflict(const svn_wc_conflict_description3_t *actual,
-                 const svn_wc_conflict_description3_t *expected)
+compare_conflict(const svn_wc_conflict_description2_t *actual,
+                 const svn_wc_conflict_description2_t *expected)
 {
   if (actual == NULL && expected == NULL)
     return SVN_NO_ERROR;
@@ -98,16 +98,16 @@ compare_conflict(const svn_wc_conflict_d
 
   ASSERT_INT_EQ(actual->kind,           expected->kind);
   ASSERT_STR_EQ(actual->local_abspath,  expected->local_abspath);
-  ASSERT_INT_EQ(actual->local_node_kind,expected->local_node_kind);
+  ASSERT_INT_EQ(actual->node_kind,      expected->node_kind);
   ASSERT_STR_EQ(actual->property_name,  expected->property_name);
   ASSERT_INT_EQ(actual->is_binary,      expected->is_binary);
   ASSERT_STR_EQ(actual->mime_type,      expected->mime_type);
-  ASSERT_INT_EQ(actual->incoming_change, expected->incoming_change);
-  ASSERT_INT_EQ(actual->local_change,   expected->local_change);
+  ASSERT_INT_EQ(actual->action,         expected->action);
+  ASSERT_INT_EQ(actual->reason,         expected->reason);
   ASSERT_STR_EQ(actual->base_abspath,   expected->base_abspath);
   ASSERT_STR_EQ(actual->their_abspath,  expected->their_abspath);
   ASSERT_STR_EQ(actual->my_abspath,     expected->my_abspath);
-  ASSERT_STR_EQ(actual->merged_abspath, expected->merged_abspath);
+  ASSERT_STR_EQ(actual->merged_file,    expected->merged_file);
   ASSERT_INT_EQ(actual->operation,      expected->operation);
   SVN_ERR(compare_version(actual->src_left_version,
                           expected->src_left_version));
@@ -134,7 +134,7 @@ compare_file_content(const char *file_ab
  * conflict, or are both NULL.  Return an error if not.
  *
  * Compare the property values found in files named by
- * ACTUAL->base_abspath, ACTUAL->my_abspath, ACTUAL->merged_abspath
+ * ACTUAL->base_abspath, ACTUAL->my_abspath, ACTUAL->merged_file
  * with EXPECTED_BASE_VAL, EXPECTED_MY_VAL, EXPECTED_THEIR_VAL
  * respectively, ignoring the corresponding fields in EXPECTED. */
 static svn_error_t *
@@ -181,7 +181,7 @@ compare_prop_conflict(const svn_wc_confl
 }
 
 /* Create and return a tree conflict description */
-static svn_wc_conflict_description3_t *
+static svn_wc_conflict_description2_t *
 tree_conflict_create(const char *local_abspath,
                      svn_node_kind_t node_kind,
                      svn_wc_operation_t operation,
@@ -198,26 +198,26 @@ tree_conflict_create(const char *local_a
                      apr_pool_t *result_pool)
 {
   svn_wc_conflict_version_t *left, *right;
-  svn_wc_conflict_description3_t *conflict;
+  svn_wc_conflict_description2_t *conflict;
 
   left = svn_wc_conflict_version_create2(left_repo, NULL, left_path,
                                          left_revnum, left_kind, result_pool);
   right = svn_wc_conflict_version_create2(right_repo, NULL, right_path,
                                           right_revnum, right_kind,
                                           result_pool);
-  conflict = svn_wc_conflict_description_create_tree3(
+  conflict = svn_wc_conflict_description_create_tree2(
                     local_abspath, node_kind, operation,
                     left, right, result_pool);
-  conflict->incoming_change = action;
-  conflict->local_change = reason;
+  conflict->action = action;
+  conflict->reason = reason;
   return conflict;
 }
 
 static svn_error_t *
 test_deserialize_tree_conflict(apr_pool_t *pool)
 {
-  const svn_wc_conflict_description3_t *conflict;
-  svn_wc_conflict_description3_t *exp_conflict;
+  const svn_wc_conflict_description2_t *conflict;
+  svn_wc_conflict_description2_t *exp_conflict;
   const char *tree_conflict_data;
   const char *local_abspath;
   const svn_skel_t *skel;
@@ -226,18 +226,18 @@ test_deserialize_tree_conflict(apr_pool_
                         "(version 0  2 -1 0  0 ) (version 0  2 -1 0  0 ))";
 
   SVN_ERR(svn_dirent_get_absolute(&local_abspath, "Foo.c", pool));
-  exp_conflict = svn_wc_conflict_description_create_tree3(
+  exp_conflict = svn_wc_conflict_description_create_tree2(
                         local_abspath, svn_node_file, svn_wc_operation_update,
                         NULL, NULL, pool);
-  exp_conflict->incoming_change = svn_wc_conflict_action_delete;
-  exp_conflict->local_change = svn_wc_conflict_reason_edited;
+  exp_conflict->action = svn_wc_conflict_action_delete;
+  exp_conflict->reason = svn_wc_conflict_reason_edited;
 
   skel = svn_skel__parse(tree_conflict_data, strlen(tree_conflict_data), pool);
   SVN_ERR(svn_wc__deserialize_conflict(&conflict, skel, "", pool, pool));
 
-  if ((conflict->local_node_kind != exp_conflict->local_node_kind) ||
-      (conflict->incoming_change != exp_conflict->incoming_change) ||
-      (conflict->local_change != exp_conflict->local_change) ||
+  if ((conflict->node_kind != exp_conflict->node_kind) ||
+      (conflict->action != exp_conflict->action) ||
+      (conflict->reason != exp_conflict->reason) ||
       (conflict->operation != exp_conflict->operation) ||
       (strcmp(conflict->local_abspath, exp_conflict->local_abspath) != 0))
     return fail(pool, "Unexpected tree conflict");
@@ -248,7 +248,7 @@ test_deserialize_tree_conflict(apr_pool_
 static svn_error_t *
 test_serialize_tree_conflict_data(apr_pool_t *pool)
 {
-  svn_wc_conflict_description3_t *conflict;
+  svn_wc_conflict_description2_t *conflict;
   const char *tree_conflict_data;
   const char *expected;
   const char *local_abspath;
@@ -256,11 +256,11 @@ test_serialize_tree_conflict_data(apr_po
 
   SVN_ERR(svn_dirent_get_absolute(&local_abspath, "Foo.c", pool));
 
-  conflict = svn_wc_conflict_description_create_tree3(
+  conflict = svn_wc_conflict_description_create_tree2(
                     local_abspath, svn_node_file, svn_wc_operation_update,
                     NULL, NULL, pool);
-  conflict->incoming_change = svn_wc_conflict_action_delete;
-  conflict->local_change = svn_wc_conflict_reason_edited;
+  conflict->action = svn_wc_conflict_action_delete;
+  conflict->reason = svn_wc_conflict_reason_edited;
 
   SVN_ERR(svn_wc__serialize_conflict(&skel, conflict, pool, pool));
   tree_conflict_data = svn_skel__unparse(skel, pool)->data;
@@ -285,7 +285,7 @@ test_read_write_tree_conflicts(const svn
 
   const char *parent_abspath;
   const char *child1_abspath, *child2_abspath;
-  svn_wc_conflict_description3_t *conflict1, *conflict2;
+  svn_wc_conflict_description2_t *conflict1, *conflict2;
 
   SVN_ERR(svn_test__sandbox_create(&sbox, "read_write_tree_conflicts", opts, 
pool));
   parent_abspath = svn_dirent_join(sbox.wc_abspath, "A", pool);
@@ -337,7 +337,7 @@ test_read_write_tree_conflicts(const svn
 
   /* Read conflicts back */
   {
-    const svn_wc_conflict_description3_t *read_conflict;
+    const svn_wc_conflict_description2_t *read_conflict;
 
     SVN_ERR(svn_wc__get_tree_conflict(&read_conflict, sbox.wc_ctx,
                                       child1_abspath, pool, pool));
@@ -606,20 +606,20 @@ test_serialize_tree_conflict(const svn_t
   SVN_TEST_ASSERT(complete); /* Everything available */
 
   {
-    svn_wc_conflict_reason_t local_change;
-    svn_wc_conflict_action_t incoming_change;
+    svn_wc_conflict_reason_t reason;
+    svn_wc_conflict_action_t action;
     const char *moved_away_op_root_abspath;
 
-    SVN_ERR(svn_wc__conflict_read_tree_conflict(&local_change,
-                                                &incoming_change,
+    SVN_ERR(svn_wc__conflict_read_tree_conflict(&reason,
+                                                &action,
                                                 &moved_away_op_root_abspath,
                                                 sbox.wc_ctx->db,
                                                 sbox.wc_abspath,
                                                 conflict_skel,
                                                 pool, pool));
 
-    SVN_TEST_ASSERT(local_change == svn_wc_conflict_reason_moved_away);
-    SVN_TEST_ASSERT(incoming_change == svn_wc_conflict_action_delete);
+    SVN_TEST_ASSERT(reason == svn_wc_conflict_reason_moved_away);
+    SVN_TEST_ASSERT(action == svn_wc_conflict_action_delete);
     SVN_TEST_ASSERT(!strcmp(moved_away_op_root_abspath,
                             sbox_wc_path(&sbox, "A/B")));
   }

Modified: subversion/trunk/tools/dev/svnraisetreeconflict/svnraisetreeconflict.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/tools/dev/svnraisetreeconflict/svnraisetreeconflict.c?rev=1618906&r1=1618905&r2=1618906&view=diff
==============================================================================
--- subversion/trunk/tools/dev/svnraisetreeconflict/svnraisetreeconflict.c 
(original)
+++ subversion/trunk/tools/dev/svnraisetreeconflict/svnraisetreeconflict.c Tue 
Aug 19 17:26:20 2014
@@ -170,7 +170,7 @@ raise_tree_conflict(int argc, const char
 {
   int i = 0;
   svn_wc_conflict_version_t *left, *right;
-  svn_wc_conflict_description3_t *c;
+  svn_wc_conflict_description2_t *c;
   svn_wc_context_t *wc_ctx;
 
   /* Conflict description parameters */
@@ -206,10 +206,10 @@ raise_tree_conflict(int argc, const char
                                          peg_rev1, kind1, pool);
   right = svn_wc_conflict_version_create2(repos_url2, NULL, path_in_repos2,
                                           peg_rev2, kind2, pool);
-  c = svn_wc_conflict_description_create_tree3(wc_abspath, kind,
-                                              operation, left, right, pool);
-  c->incoming_change = (svn_wc_conflict_action_t)action;
-  c->local_change = (svn_wc_conflict_reason_t)reason;
+  c = svn_wc_conflict_description_create_tree2(wc_abspath, kind,
+                                               operation, left, right, pool);
+  c->action = (svn_wc_conflict_action_t)action;
+  c->reason = (svn_wc_conflict_reason_t)reason;
 
   /* Raise the conflict */
   SVN_ERR(svn_wc_context_create(&wc_ctx, NULL, pool, pool));


Reply via email to
--- subversion/trunk/subversion/svn/conflict-callbacks.c (original)
+++ subversion/trunk/subversion/svn/conflict-callbacks.c Tue Aug 19 17:26:20 
2014
@@ -127,7 +127,7 @@ svn_cl__accept_from_word(const char *wor
 /* Print on stdout a diff that shows incoming conflicting changes
  * corresponding to the conflict described in DESC. */
 static svn_error_t *
-show_diff(const svn_wc_conflict_description3_t *desc,
+show_diff(const svn_wc_conflict_description2_t *desc,
           const char *path_prefix,
           svn_cancel_func_t cancel_func,
           void *cancel_baton,
@@ -139,7 +139,7 @@ show_diff(const svn_wc_conflict_descript
   svn_stream_t *output;
   svn_diff_file_options_t *options;
 
-  if (desc->merged_abspath)
+  if (desc->merged_file)
     {
       /* For conflicts recorded by the 'merge' operation, show a diff between
        * 'mine' (the working version of the file as it appeared before the
@@ -163,7 +163,7 @@ show_diff(const svn_wc_conflict_descript
           path1 = desc->their_abspath;
           label1 = _("THEIRS");
         }
-      path2 = desc->merged_abspath;
+      path2 = desc->merged_file;
       label2 = _("MERGED");
     }
   else
@@ -203,7 +203,7 @@ show_diff(const svn_wc_conflict_descript
 /* Print on stdout just the conflict hunks of a diff among the 'base', 'their'
  * and 'my' files of DESC. */
 static svn_error_t *
-show_conflicts(const svn_wc_conflict_description3_t *desc,
+show_conflicts(const svn_wc_conflict_description2_t *desc,
                svn_cancel_func_t cancel_func,
                void *cancel_baton,
                apr_pool_t *pool)
@@ -246,7 +246,7 @@ show_conflicts(const svn_wc_conflict_des
  */
 static svn_error_t *
 merge_prop_conflict(svn_stream_t *output,
-                    const svn_wc_conflict_description3_t *desc,
+                    const svn_wc_conflict_description2_t *desc,
                     const char *merged_abspath,
                     svn_cancel_func_t cancel_func,
                     void *cancel_baton,
@@ -306,7 +306,7 @@ merge_prop_conflict(svn_stream_t *output
  * Assume the values are printable UTF-8 text.
  */
 static svn_error_t *
-show_prop_conflict(const svn_wc_conflict_description3_t *desc,
+show_prop_conflict(const svn_wc_conflict_description2_t *desc,
                    const char *merged_abspath,
                    svn_cancel_func_t cancel_func,
                    void *cancel_baton,
@@ -370,7 +370,7 @@ open_editor(svn_boolean_t *performed_edi
  * environment variables; see svn_cl__edit_file_externally() for details. */
 static svn_error_t *
 edit_prop_conflict(const char **merged_file_path,
-                   const svn_wc_conflict_description3_t *desc,
+                   const svn_wc_conflict_description2_t *desc,
                    svn_cl__interactive_conflict_baton_t *b,
                    apr_pool_t *result_pool,
                    apr_pool_t *scratch_pool)
@@ -692,7 +692,7 @@ prompt_user(const resolver_option_t **op
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_text_conflict(svn_wc_conflict_result_t *result,
-                     const svn_wc_conflict_description3_t *desc,
+                     const svn_wc_conflict_description2_t *desc,
                      svn_cl__interactive_conflict_baton_t *b,
                      apr_pool_t *scratch_pool)
 {
@@ -718,7 +718,7 @@ handle_text_conflict(svn_wc_conflict_res
      markers to the user (this is the typical 3-way merge
      scenario), or if no base is available, we can show a diff
      between mine and theirs. */
-  if ((desc->merged_abspath && desc->base_abspath)
+  if ((desc->merged_file && desc->base_abspath)
       || (!desc->base_abspath && desc->my_abspath && desc->their_abspath))
     diff_allowed = TRUE;
 
@@ -815,8 +815,7 @@ handle_text_conflict(svn_wc_conflict_res
         }
       else if (strcmp(opt->code, "e") == 0 || strcmp(opt->code, ":-E") == 0)
         {
-          SVN_ERR(open_editor(&performed_edit, desc->merged_abspath, b,
-                              iterpool));
+          SVN_ERR(open_editor(&performed_edit, desc->merged_file, b, 
iterpool));
           if (performed_edit)
             knows_something = TRUE;
         }
@@ -828,7 +827,7 @@ handle_text_conflict(svn_wc_conflict_res
           err = svn_cl__merge_file_externally(desc->base_abspath,
                                               desc->their_abspath,
                                               desc->my_abspath,
-                                              desc->merged_abspath,
+                                              desc->merged_file,
                                               desc->local_abspath, b->config,
                                               NULL, iterpool);
           if (err)
@@ -843,7 +842,7 @@ handle_text_conflict(svn_wc_conflict_res
                                              desc->base_abspath,
                                              desc->their_abspath,
                                              desc->my_abspath,
-                                             desc->merged_abspath,
+                                             desc->merged_file,
                                              desc->local_abspath,
                                              b->path_prefix,
                                              b->editor_cmd,
@@ -881,10 +880,10 @@ handle_text_conflict(svn_wc_conflict_res
         {
           /* ### This check should be earlier as it's nasty to offer an option
            *     and then when the user chooses it say 'Invalid option'. */
           /* ### 'merged_abspath' shouldn't be necessary *before* we launch the
            *     resolver: it should be the *result* of doing so. */
           if (desc->base_abspath && desc->their_abspath &&
-              desc->my_abspath && desc->merged_abspath)
+              desc->my_abspath && desc->merged_file)
             {
               svn_error_t *err;
               char buf[1024];
@@ -893,7 +892,7 @@ handle_text_conflict(svn_wc_conflict_res
               err = svn_cl__merge_file_externally(desc->base_abspath,
                                                   desc->their_abspath,
                                                   desc->my_abspath,
-                                                  desc->merged_abspath,
+                                                  desc->merged_file,
                                                   desc->local_abspath,
                                                   b->config, NULL, iterpool);
               if (err && (err->apr_err == SVN_ERR_CL_NO_EXTERNAL_MERGE_TOOL ||
@@ -924,7 +923,7 @@ handle_text_conflict(svn_wc_conflict_res
                                      desc->base_abspath,
                                      desc->their_abspath,
                                      desc->my_abspath,
-                                     desc->merged_abspath,
+                                     desc->merged_file,
                                      desc->local_abspath,
                                      b->path_prefix,
                                      b->editor_cmd,
@@ -979,7 +978,7 @@ handle_text_conflict(svn_wc_conflict_res
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_prop_conflict(svn_wc_conflict_result_t *result,
-                     const svn_wc_conflict_description3_t *desc,
+                     const svn_wc_conflict_description2_t *desc,
                      svn_cl__interactive_conflict_baton_t *b,
                      apr_pool_t *result_pool,
                      apr_pool_t *scratch_pool)
@@ -989,6 +988,12 @@ handle_prop_conflict(svn_wc_conflict_res
   const char *merged_file_path = NULL;
   svn_boolean_t resolved_allowed = FALSE;
 
+  /* ### Work around a historical bug in the provider: the path to the
+   *     conflict description file was put in the 'theirs' field, and
+   *     'theirs' was put in the 'merged' field. */
+  ((svn_wc_conflict_description2_t *)desc)->their_abspath = desc->merged_file;
+  ((svn_wc_conflict_description2_t *)desc)->merged_file = NULL;
+
   SVN_ERR_ASSERT(desc->kind == svn_wc_conflict_kind_property);
 
   SVN_ERR(svn_cmdline_fprintf(stderr, scratch_pool,
@@ -1078,7 +1083,7 @@ handle_prop_conflict(svn_wc_conflict_res
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_tree_conflict(svn_wc_conflict_result_t *result,
-                     const svn_wc_conflict_description3_t *desc,
+                     const svn_wc_conflict_description2_t *desc,
                      svn_cl__interactive_conflict_baton_t *b,
                      apr_pool_t *scratch_pool)
 {
@@ -1108,15 +1113,15 @@ handle_tree_conflict(svn_wc_conflict_res
       if (desc->operation == svn_wc_operation_update ||
           desc->operation == svn_wc_operation_switch)
         {
-          if (desc->local_change == svn_wc_conflict_reason_moved_away)
+          if (desc->reason == svn_wc_conflict_reason_moved_away)
             {
               tc_opts = tree_conflict_options_update_moved_away;
             }
-          else if (desc->local_change == svn_wc_conflict_reason_deleted ||
-                   desc->local_change == svn_wc_conflict_reason_replaced)
+          else if (desc->reason == svn_wc_conflict_reason_deleted ||
+                   desc->reason == svn_wc_conflict_reason_replaced)
             {
-              if (desc->incoming_change == svn_wc_conflict_action_edit &&
-                  desc->local_node_kind == svn_node_dir)
+              if (desc->action == svn_wc_conflict_action_edit &&
+                  desc->node_kind == svn_node_dir)
                 tc_opts = tree_conflict_options_update_edit_deleted_dir;
             }
         }
@@ -1149,7 +1154,7 @@ handle_tree_conflict(svn_wc_conflict_res
  * SCRATCH_POOL is used for temporary allocations. */
 static svn_error_t *
 handle_obstructed_add(svn_wc_conflict_result_t *result,
-                      const svn_wc_conflict_description3_t *desc,
+                      const svn_wc_conflict_description2_t *desc,
                       svn_cl__interactive_conflict_baton_t *b,
                       apr_pool_t *scratch_pool)
 {
@@ -1196,7 +1201,7 @@ handle_obstructed_add(svn_wc_conflict_re
 /* The body of svn_cl__conflict_func_interactive(). */
 static svn_error_t *
 conflict_func_interactive(svn_wc_conflict_result_t **result,
-                          const svn_wc_conflict_description3_t *desc,
+                          const svn_wc_conflict_description2_t *desc,
                           void *baton,
                           apr_pool_t *result_pool,
                           apr_pool_t *scratch_pool)
@@ -1223,7 +1228,7 @@ conflict_func_interactive(svn_wc_conflic
     case svn_cl__accept_working:
       /* If the caller didn't merge the property values, then I guess
        * 'choose working' means 'choose mine'... */
-      if (! desc->merged_abspath)
+      if (! desc->merged_file)
         (*result)->merged_file = desc->my_abspath;
       (*result)->choice = svn_wc_conflict_choose_merged;
       return SVN_NO_ERROR;
@@ -1240,7 +1245,7 @@ conflict_func_interactive(svn_wc_conflic
       (*result)->choice = svn_wc_conflict_choose_theirs_full;
       return SVN_NO_ERROR;
     case svn_cl__accept_edit:
-      if (desc->merged_abspath)
+      if (desc->merged_file)
         {
           if (b->external_failed)
             {
@@ -1248,7 +1253,7 @@ conflict_func_interactive(svn_wc_conflic
               return SVN_NO_ERROR;
             }
 
-          err = svn_cmdline__edit_file_externally(desc->merged_abspath,
+          err = svn_cmdline__edit_file_externally(desc->merged_file,
                                                   b->editor_cmd, b->config,
                                                   scratch_pool);
           if (err && (err->apr_err == SVN_ERR_CL_NO_EXTERNAL_EDITOR ||
@@ -1272,7 +1277,7 @@ conflict_func_interactive(svn_wc_conflic
       break;
     case svn_cl__accept_launch:
       if (desc->base_abspath && desc->their_abspath
-          && desc->my_abspath && desc->merged_abspath)
+          && desc->my_abspath && desc->merged_file)
         {
           svn_boolean_t remains_in_conflict;
 
@@ -1285,7 +1290,7 @@ conflict_func_interactive(svn_wc_conflic
           err = svn_cl__merge_file_externally(desc->base_abspath,
                                               desc->their_abspath,
                                               desc->my_abspath,
-                                              desc->merged_abspath,
+                                              desc->merged_file,
                                               desc->local_abspath,
                                               b->config,
                                               &remains_in_conflict,
@@ -1331,8 +1336,8 @@ conflict_func_interactive(svn_wc_conflic
      Conflicting edits on a property.
   */
   if (((desc->kind == svn_wc_conflict_kind_text)
-       && (desc->incoming_change == svn_wc_conflict_action_edit)
-       && (desc->local_change == svn_wc_conflict_reason_edited)))
+       && (desc->action == svn_wc_conflict_action_edit)
+       && (desc->reason == svn_wc_conflict_reason_edited)))
     SVN_ERR(handle_text_conflict(*result, desc, b, scratch_pool));
   else if (desc->kind == svn_wc_conflict_kind_property)
     SVN_ERR(handle_prop_conflict(*result, desc, b, result_pool, scratch_pool));
@@ -1355,8 +1360,8 @@ conflict_func_interactive(svn_wc_conflic
       postpone               [              bail out                 ]
 
    */
-  else if ((desc->incoming_change == svn_wc_conflict_action_add)
-           && (desc->local_change == svn_wc_conflict_reason_obstructed))
+  else if ((desc->action == svn_wc_conflict_action_add)
+           && (desc->reason == svn_wc_conflict_reason_obstructed))
     SVN_ERR(handle_obstructed_add(*result, desc, b, scratch_pool));
 
   else if (desc->kind == svn_wc_conflict_kind_tree)
@@ -1372,7 +1377,7 @@ conflict_func_interactive(svn_wc_conflic
 
 svn_error_t *
 svn_cl__conflict_func_interactive(svn_wc_conflict_result_t **result,
-                                  const svn_wc_conflict_description3_t *desc,
+                                  const svn_wc_conflict_description2_t *desc,
                                   void *baton,
                                   apr_pool_t *result_pool,
                                   apr_pool_t *scratch_pool)
@@ -881,10 +880,10 @@ handle_text_conflict(svn_wc_conflict_res
           /* ### This check should be earlier as it's nasty to offer an option
            *     and then when the user chooses it say 'Invalid option'. */
-          /* ### 'merged_abspath' shouldn't be necessary *before* we launch the
+          /* ### 'merged_file' shouldn't be necessary *before* we launch the
            *     resolver: it should be the *result* of doing so. */
           if (desc->base_abspath && desc->their_abspath &&

Modified: subversion/trunk/subversion/svn/info-cmd.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/info-cmd.c?rev=1618906&r1=1618905&r2=1618906&view=diff
==============================================================================